@@ -374,7 +374,10 @@ class fMMS_SenderUI(hildon.Program):
 				if output['Response-Status'] == "Ok":
 					log.info("message seems to have sent AOK!")
 					banner = hildon.hildon_banner_show_information(self.spawner, "", "Message sent")
-					self.quit()
+					if self.window == self.spawner:
+						self.quit()
+					else:
+						self.window.destroy()
 					return
 			
 			message = str(status) + "_" + str(reason)
